﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Charts;

namespace LegendWithWrapPanel
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataContext = ChartData.GenerateData(10);
        
        }
 
    }

    public class CustomLegend : LegendBase
    {
        #region Members
        ItemsControl _itemsControl;
        #endregion

        #region Constructor

     
        public CustomLegend()
        {
            DefaultStyleKey = typeof(CustomLegend);

            ItemsPanel = XamlReader.Parse(
                @"
                <ItemsPanelTemplate
                    xmlns=""http://schemas.microsoft.com/winfx/2006/xaml/presentation"">
                  <StackPanel Orientation=""Horizontal""
                              VerticalAlignment=""Center""
                              HorizontalAlignment=""Center""/>
                </ItemsPanelTemplate>") as ItemsPanelTemplate;

        }


        #endregion

        #region Overrides
         
        protected override void AddChildInOrder(UIElement legendItem, Series series)
        { 
            if (!Children.Contains(legendItem)) 
                Children.Add(legendItem);     
        } 

        public override void OnApplyTemplate()
        {
            _itemsControl = GetTemplateChild("itemsControl") as ItemsControl;
            if (_itemsControl != null)
            {
                _itemsControl.SetBinding(ItemsControl.ItemsSourceProperty,
                    new Binding("Children")
                    {
                        Source = this
                    });

                _itemsControl.ItemsPanel = ItemsPanel;
            }
            base.OnApplyTemplate();
        }

        #endregion

        #region Public Properties



        public ItemsPanelTemplate ItemsPanel
        {
            get { return (ItemsPanelTemplate)GetValue(ItemsPanelProperty); }
            set { SetValue(ItemsPanelProperty, value); }
        }

        public static readonly DependencyProperty ItemsPanelProperty =
            DependencyProperty.Register(
                "ItemsPanel",
                typeof(ItemsPanelTemplate),
                typeof(CustomLegend),
                new PropertyMetadata(null, 
                    (ss, ee) => 
                    {
                        if (ee.NewValue is ItemsPanelTemplate)
                        {
                            CustomLegend legend = ss as CustomLegend;
                            if (legend._itemsControl != null)
                                legend._itemsControl.ItemsPanel = ee.NewValue as ItemsPanelTemplate;
                        }
                    }));



        #endregion
    }



    public class ChartData
    {
        public DateTime Date { get; set; }
        public int Index { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }
        public double Value4 { get; set; }
        public double Value5 { get; set; }
        public double Value6 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Index = 0,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
                Value4 = r.Next(20, 40),
                Value5 = r.Next(20, 40),
                Value6 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                    Index = i,
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                    dat.Value4 = data[i - 1].Value3 + r.NextDouble();
                    dat.Value5 = data[i - 1].Value3 + r.NextDouble();
                    dat.Value6 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                    dat.Value4 = data[i - 1].Value3 - r.NextDouble();
                    dat.Value5 = data[i - 1].Value3 - r.NextDouble();
                    dat.Value6 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
